@@ -362,10 +362,15 @@ class MapHardwareTypeToImageRepository(str, Enum):
 class HardwareImageDistribution(str, Enum):
     J46 = "j46"
     J50 = "j50"
+    J502 = "j502"
 
     @property
     def python_version(self):
-        dist_to_version = {HardwareImageDistribution.J46: "3.6", HardwareImageDistribution.J50: "3.8"}
+        dist_to_version = {
+            HardwareImageDistribution.J46: "3.6",
+            HardwareImageDistribution.J50: "3.8",
+            HardwareImageDistribution.J502: "3.8",
+        }
         return dist_to_version[self]
 
 
@@ -374,8 +379,8 @@ class MapHardwareTypeToImageDistribution(str, Enum):
     XAVIER = HardwareImageDistribution.J46.value
     XAVIER_AGX = HardwareImageDistribution.J46.value
     ORIN = HardwareImageDistribution.J50.value
-    ORIN_NX = HardwareImageDistribution.J50.value
-    ORIN_NANO = HardwareImageDistribution.J50.value
+    ORIN_NX = HardwareImageDistribution.J502.value
+    ORIN_NANO = HardwareImageDistribution.J502.value
 
 
 class MapHardwareTypeToGroup(str, Enum):
